[MPlayer-cvslog] r23892 - in trunk: playtree.c playtree.h

diego subversion at mplayerhq.hu
Sat Jul 28 16:27:55 CEST 2007


Author: diego
Date: Sat Jul 28 16:27:55 2007
New Revision: 23892

Log:
typo fix: childs --> children


Modified:
   trunk/playtree.c
   trunk/playtree.h

Modified: trunk/playtree.c
==============================================================================
--- trunk/playtree.c	(original)
+++ trunk/playtree.c	Sat Jul 28 16:27:55 2007
@@ -28,14 +28,14 @@ play_tree_new(void) {
 }
 
 void
-play_tree_free(play_tree_t* pt, int childs) {
+play_tree_free(play_tree_t* pt, int children) {
   play_tree_t* iter;
 
 #ifdef MP_DEBUG
   assert(pt != NULL);
 #endif
 
-  if(childs) {    
+  if(children) {    
     for(iter = pt->child; iter != NULL; ) {
       play_tree_t* nxt=iter->next;
       play_tree_free(iter,1);
@@ -61,7 +61,7 @@ play_tree_free(play_tree_t* pt, int chil
 }
 
 void
-play_tree_free_list(play_tree_t* pt, int childs) {
+play_tree_free_list(play_tree_t* pt, int children) {
   play_tree_t* iter;
 
 #ifdef MP_DEBUG
@@ -73,7 +73,7 @@ play_tree_free_list(play_tree_t* pt, int
 
   while(iter) {
     play_tree_t* nxt = iter->next;
-    play_tree_free(iter,childs);
+    play_tree_free(iter, children);
     iter = nxt;
   }
     
@@ -149,7 +149,7 @@ play_tree_insert_entry(play_tree_t* pt, 
 }
     
 void
-play_tree_remove(play_tree_t* pt, int free_it,int with_childs) {
+play_tree_remove(play_tree_t* pt, int free_it, int with_children) {
 
 #ifdef MP_DEBUG
   assert(pt != NULL);
@@ -191,7 +191,7 @@ play_tree_remove(play_tree_t* pt, int fr
 
   pt->prev = pt->next = pt->parent = NULL;
   if(free_it)
-    play_tree_free(pt,with_childs);
+    play_tree_free(pt,with_children);
 
 }
 
@@ -204,7 +204,7 @@ play_tree_set_child(play_tree_t* pt, pla
   assert(pt->entry_type == PLAY_TREE_ENTRY_NODE);
 #endif
 
   //DEBUG_FF: Where are the childs freed ?
   // Attention in using this function!
   for(iter = pt->child ; iter != NULL ; iter = iter->next)
     iter->parent = NULL;
@@ -405,7 +405,7 @@ play_tree_set_params_from(play_tree_t* d
 
 }
 
 // all childs if deep < 0
 void
 play_tree_set_flag(play_tree_t* pt, int flags , int deep) {
   play_tree_t*  i;
@@ -614,7 +614,7 @@ play_tree_iter_step(play_tree_iter_t* it
 
   }
 
-  // Is there any valid childs ?
+  // Is there any valid child?
   if(pt->child && play_tree_is_valid(pt->child)) {
     iter->tree = pt;
     if(with_nodes) { // Stop on the node      
@@ -623,7 +623,7 @@ play_tree_iter_step(play_tree_iter_t* it
       return play_tree_iter_down_step(iter,d,with_nodes);
   }
 
-  // Is it a valid enty ?
+  // Is it a valid entry?
   if(! play_tree_is_valid(pt)) {
     if(d == 0) { // Can this happen ? FF: Yes!
       mp_msg(MSGT_PLAYTREE,MSGL_ERR,"What to do now ???? Infinite loop if we continue\n");
@@ -204,7 +204,7 @@ play_tree_set_child(play_tree_t* pt, pla
 #endif
 
-  //DEBUG_FF: Where are the childs freed ?
+  //DEBUG_FF: Where are the children freed?
   // Attention in using this function!
   for(iter = pt->child ; iter != NULL ; iter = iter->next)
@@ -405,7 +405,7 @@ play_tree_set_params_from(play_tree_t* d
 }
 
-// all childs if deep < 0
+// all children if deep < 0
 void
 play_tree_set_flag(play_tree_t* pt, int flags , int deep) {

Modified: trunk/playtree.h
==============================================================================
--- trunk/playtree.h	(original)
+++ trunk/playtree.h	Sat Jul 28 16:27:55 2007
@@ -31,7 +31,7 @@ struct m_config;
 /// \defgroup PlaytreeEntryFlags Playtree flags
 /// \ingroup Playtree
 ///@{
 /// Play the item childs in random order.
 #define PLAY_TREE_RND  (1<<0)
 /// Playtree flags used by the iterator to mark items already "randomly" played.
 #define PLAY_TREE_RND_PLAYED  (1<<8)
@@ -121,21 +121,21 @@ play_tree_new(void);
 
 /// Free a playtree item.
 /** \param pt Item to free.
  *  \param childs If non-zero the item's childs are recursively freed.
  */
 void
-play_tree_free(play_tree_t* pt, int childs);
+play_tree_free(play_tree_t* pt, int children);
 
 
 /// Free an item and its siblings.
 /** \param pt Item to free.
  *  \param childs If non-zero the items' childs are recursively freed.
  */
 void
-play_tree_free_list(play_tree_t* pt, int childs);
+play_tree_free_list(play_tree_t* pt, int children);
 
 
 /// Set the childs of a playtree item.
 void
 play_tree_set_child(play_tree_t* pt, play_tree_t* child);
 
@@ -158,7 +158,7 @@ play_tree_insert_entry(play_tree_t* pt, 
 
 /// Detach an item from the tree.
 void
-play_tree_remove(play_tree_t* pt, int free_it,int with_childs);
+play_tree_remove(play_tree_t* pt, int free_it,int with_children);
 
 /// Add a file to an item.
 void
@@ -199,7 +199,7 @@ play_tree_iter_free(play_tree_iter_t* it
 /// Step an iterator.
 /** \param iter The iterator.
  *  \param d The direction: d > 0 == next , d < 0 == prev
  *  \param with_node TRUE == stop on nodes with childs, FALSE == go directly to the next child
  *  \return See \ref PlaytreeIterReturn.
  */
 int 
@@ -208,7 +208,7 @@ play_tree_iter_step(play_tree_iter_t* it
 /// Step up, useful to break a loop, etc.
 /** \param iter The iterator.
  *  \param d The direction: d > 0 == next , d < 0 == prev
  *  \param with_node TRUE == stop on nodes with childs, FALSE == go directly to the next child
  *  \return See \ref PlaytreeIterReturn.
  */
 int
@@ -31,7 +31,7 @@ struct m_config;
 /// \ingroup Playtree
 ///@{
-/// Play the item childs in random order.
+/// Play the item children in random order.
 #define PLAY_TREE_RND  (1<<0)
 /// Playtree flags used by the iterator to mark items already "randomly" played.
@@ -121,21 +121,21 @@ play_tree_new(void);
 /// Free a playtree item.
 /** \param pt Item to free.
- *  \param childs If non-zero the item's childs are recursively freed.
+ *  \param children If non-zero the item's children are recursively freed.
  */
 void
@@ -121,21 +121,21 @@ play_tree_new(void);
 /// Free an item and its siblings.
 /** \param pt Item to free.
- *  \param childs If non-zero the items' childs are recursively freed.
+ *  \param children If non-zero the items' children are recursively freed.
  */
 void
@@ -121,21 +121,21 @@ play_tree_new(void);
 
 
-/// Set the childs of a playtree item.
+/// Set the children of a playtree item.
 void
 play_tree_set_child(play_tree_t* pt, play_tree_t* child);
@@ -199,7 +199,7 @@ play_tree_iter_free(play_tree_iter_t* it
 /** \param iter The iterator.
  *  \param d The direction: d > 0 == next , d < 0 == prev
- *  \param with_node TRUE == stop on nodes with childs, FALSE == go directly to the next child
+ *  \param with_node TRUE == stop on nodes with children, FALSE == go directly to the next child
  *  \return See \ref PlaytreeIterReturn.
  */
@@ -208,7 +208,7 @@ play_tree_iter_step(play_tree_iter_t* it
 /** \param iter The iterator.
  *  \param d The direction: d > 0 == next , d < 0 == prev
- *  \param with_node TRUE == stop on nodes with childs, FALSE == go directly to the next child
+ *  \param with_node TRUE == stop on nodes with children, FALSE == go directly to the next child
  *  \return See \ref PlaytreeIterReturn.
  */



More information about the MPlayer-cvslog mailing list